cscript
*global data_directory "YOUR DIRECTORY HERE"
global data_directory "C:\Users\gas\Documents\webinars\2022\time_series\data"

///////////////////  EXAMPLE 1 ///////////////
/* Import data from FRED */
cd "$data_directory"
import fred SP500 CBBTCUSD VIXCLS, daterange(2017-01-03 2022-08-31) 
rename SP500     sp500
rename VIXCLS    vix
rename CBBTCUSD  bitcoin

describe
tsset daten,daily
list daten sp500 bitcoin vix  in 1/8,sep(4)

generate bdate=bofd("bcalstocks",daten)
format bdate %tbbcalstocks
tsset bdate
drop if bdate==.
list daten bdate sp500 bitcoin vix  in 1/8,sep(4)


///////////////////  EXAMPLE 2 ///////////////
import fred CHLSACRQISMEI, daterange(1990-01-01 2010-12-31) ///
	aggregate(quarterly) clear
	
rename CHLSACRQISMEI  cars_cl
describe

generate quarter = qofd(daten)
format quarter %tq

tsset quarter

list daten quarter cars_cl if tin(1994q1,1994q4)
list quarter cars_cl L.cars_cl L2.cars_cl F.cars_cl D.cars_cl ///
     if tin(1994q1,1994q4), noobs
tsline cars_cl,                                           ///
   title("Quarterly total passenger car registrations")    ///
   subtitle("Chile 1994q1-2010q4") ytitle(" ") xtitle(" ") ///
    note(Source: Federal Reserve databank)

corrgram D.cars_cl,lags(20)

arima D.cars_cl,ar(1) 
estimates store Model_AR1
arima D.cars_cl,ma(1) 
estimates store Model_MA1

estimates table Model_AR1 Model_MA1, star stats(aic bic) b(%9.2f)
arima D.cars_cl,ar(1) nolog

///////////////////  EXAMPLE 3 ///////////////
import fred EXMXUS, daterange(2000-01-01 2022-08-15) clear

generate month=mofd(daten)
label var month "numeric (monthly) date"
rename EXMXUS exchrate_mx

tsset month,monthly

list in 1/4,abbreviate(12)

tsline exchrate_mx, name(level,replace) ytitle(level) xtitle("")
tsline D.exchrate_mx, name(difference,replace)                ///
                      ytitle(First difference) xtitle("month")
graph combine level difference,rows(2)                        ///
     title("Mexican pesos to US dollar")                      ///
     note(Source: Federal Reserve databank) 

ac D.exchrate_mx,lags(25) ytitle(" ")  name(ac_dexchrate_mx)   ///
   title("Autocorrelation function for D.exchrate_mx") ylabels(#4,angle(0))
pac D.exchrate_mx,lags(25) ytitle(" ") name(pac_dexchrate_mx)   ///
    title("Partial autocorrelation function for D.exchrate_mx") ylabels(#4,angle(0))
	
graph combine ac_dexchrate_mx pac_dexchrate_mx,rows(2) 

arch D.exchrate_mx,arch(1) garch(1) ar(1/2) nolog 
estimates store arch_ar1_2
arch D.exchrate_mx,arch(1) garch(1) ma(1) nolog 
estimates store arch_ma1
arch D.exchrate_mx,arch(1) garch(1) ma(1) ar(1/2) nolog 
estimates store arch_arma

estimates table arch_ar1_2 arch_ma1 arch_arma, ///
   star stats(aic bic) b(%9.2f) vsquish

arch D.exchrate_mx,arch(1) garch(1) ar(1/2) nolog vsquish


///////////////////  EXAMPLE 4 ///////////////

import fred SP500 CBBTCUSD VIXCLS, daterange(2017-01-02 2022-08-19) ///
   aggregate(weekly,avg) clear
rename SP500 sp500
rename CBBTCUSD bitcoin
rename VIXCLS vix

describe
tsset daten,delta(7 days)
tsline sp500,name(sp_levels,replace) ytitle("Levels")               ///
    title("S&P 500") ylabels(#3,angle(0)) xlabels(#3) xtitle("")
tsline D.sp500,name(sp_diff,replace) ytitle("First difference")      ///
    ylabels(#3,angle(0)) xlabels(#3) xtitle("")
tsline bitcoin,name(bitcoin_levels,replace) ytitle("Levels")         /// 
    title("Coinbase Bitcoin") ylabels(#3,angle(0)) xlabels(#3) xtitle("") 
tsline D.sp500,name(bitcoin_diff,replace) ytitle("First difference") ///
    ylabels(#3,angle(0)) xlabels(#3) xtitle("") 
graph combine sp_levels bitcoin_levels sp_diff bitcoin_diff,rows(2)  ///
    note(Source: Federal Reserve databank) 

tsline vix,name(vix_levels,replace) ytitle("Levels") 
tsline D.vix,name(vix_diff,replace) ytitle("First difference")   
graph combine vix_levels vix_diff,            ///
     title("Weekly CBOE Volatility Index: VIX")       ///
     note(Source: Federal Reserve databank) rows(2)

////////// Note: There is a slight difference for the result in     ///////
//////////       the VAR model that seems to be caused by a         ///////
//////////       correction in the raw data. Notice that the        /////// 
//////////       data is directly extracted from the FRED database. ///////
var D.sp500 D.bitcoin if tin(06mar2020,19aug2022), exog(D.vix) vsquish 
estimates store eq_var


irf create order1, step(10) set(myirf1,replace)
irf graph oirf
irf graph oirf,impulse(D.bitcoin) response(D.sp500) name(i_bit__r_sp,replace)
irf graph oirf,impulse(D.bitcoin) response(D.bitcoin) name(i_bit__r_bit,replace)
irf graph oirf,impulse(D.sp500) response(D.sp500) name(i_sp__r_sp,replace)
irf graph oirf,impulse(D.sp500) response(D.bitcoin) name(i_sp__r_bit,replace)

graph combine i_bit__r_sp i_bit__r_bit i_sp__r_sp i_sp__r_bit, ///
     title("Impulse-response functions")

///////////////////  EXAMPLE 5 ///////////////
arima D.vix if tin(06mar2020,19aug2022), ar(1) nolog 
estimates store eq_ar1

tsappend, add(4)
forecast create myforecast
forecast estimates eq_var,names(dsp500 dbitcoin)
forecast estimates eq_ar1,names(dvix)
forecast identity sp500=dsp500+L.sp500
forecast identity bitcoin=dbitcoin+L.bitcoin
forecast identity vix=dvix+L.vix
forecast solve, begin(td(26aug2022)) end(td(16sep2022)) prefix(f_)

list daten sp500 f_sp500 bitcoin f_bitcoin vix f_vix ///
     if tin(29jul2022,16sep2022), noobs

tsline f_sp500 sp500 if tin(01jul2022,16sep2022),         ///
    lc(red blue) ylabels(#4,angle(0)) xtitle("")          ///
	title("S&P 500 weekly forecast Aug26-Sep16") name(sp_fcst)
tsline f_bitcoin bitcoin if tin(01jul2022,16sep2022),     ///
    lc(red blue) ylabels(#4,angle(0)) xtitle("")          ///
	title("Bitcoin weekly forecast Aug26-Sep16") name(b_fcst)
graph combine sp_fcst b_fcst, rows(2)

